import { createReadOnlyTokenBridgeProgramInterface } from './utils/tokenBridge';
import { createReadOnlyWormholeProgramInterface } from './utils/wormhole';
import { createReadOnlyNftBridgeProgramInterface } from './utils/nftBridge';
/**
 * @category Solana
 */
export class SolanaContracts {
    _contracts;
    constructor(conf) {
        this._contracts = new Map();
        Object.entries(conf).forEach(([c, cfg]) => {
            this._contracts.set(c, cfg.contracts);
        });
    }
    getContracts(chain) {
        const contracts = this._contracts.get(chain);
        if (!contracts)
            throw new Error(`no Solana contracts found for ${chain}`);
        return contracts;
    }
    /**
     * Returns core wormhole contract for the chain
     *
     * @returns An interface for the core contract, errors if not found
     */
    getCore(chain, connection) {
        const contracts = this.getContracts(chain);
        if (!contracts.coreBridge)
            throw new Error(`Core contract for domain ${chain} not found`);
        return createReadOnlyWormholeProgramInterface(contracts.coreBridge, connection);
    }
    /**
     * Returns wormhole bridge contract for the chain
     *
     * @returns An interface for the bridge contract, errors if not found
     */
    getTokenBridge(chain, connection) {
        const contracts = this.getContracts(chain);
        if (!contracts.tokenBridge)
            throw new Error(`Bridge contract for domain ${chain} not found`);
        return createReadOnlyTokenBridgeProgramInterface(contracts.tokenBridge, connection);
    }
    /**
     * Returns wormhole NFT bridge contract for the chain
     *
     * @returns An interface for the NFT bridge contract, errors if not found
     */
    getNftBridge(chain, connection) {
        const contracts = this.getContracts(chain);
        if (!contracts.nftBridge)
            throw new Error(`NFT Bridge contract for domain ${chain} not found`);
        return createReadOnlyNftBridgeProgramInterface(contracts.nftBridge, connection);
    }
}
//# sourceMappingURL=contracts.js.map