import { nativeDecimals, chainToPlatform, } from '@wormhole-foundation/connect-sdk';
import { PublicKey } from '@solana/web3.js';
import { solGenesisHashToNetworkChainPair } from './constants';
import { SolanaPlatform } from './platform';
import { SolanaAddress, SolanaZeroAddress } from './address';
// forces SolanaUtils to implement PlatformUtils
var _ = SolanaUtils;
/**
 * @category Solana
 */
// Provides runtime concrete value
export var SolanaUtils;
(function (SolanaUtils) {
    function nativeTokenId(chain) {
        if (!isSupportedChain(chain))
            throw new Error(`invalid chain: ${chain}`);
        return {
            chain: chain,
            address: new SolanaAddress(SolanaZeroAddress), // TODO: fix weird type error
        };
    }
    SolanaUtils.nativeTokenId = nativeTokenId;
    function isSupportedChain(chain) {
        const platform = chainToPlatform(chain);
        return platform === SolanaPlatform.platform;
    }
    SolanaUtils.isSupportedChain = isSupportedChain;
    function isNativeTokenId(chain, tokenId) {
        if (!isSupportedChain(chain))
            return false;
        if (tokenId.chain !== chain)
            return false;
        const native = nativeTokenId(chain);
        return native == tokenId;
    }
    SolanaUtils.isNativeTokenId = isNativeTokenId;
    async function getDecimals(chain, rpc, token) {
        if (token === 'native')
            return nativeDecimals(SolanaPlatform.platform);
        let mint = await rpc.getParsedAccountInfo(new PublicKey(token.address.unwrap()));
        if (!mint)
            throw new Error('could not fetch token details');
        const { decimals } = mint.value.data.parsed.info;
        return decimals;
    }
    SolanaUtils.getDecimals = getDecimals;
    async function getBalance(chain, rpc, walletAddress, token) {
        if (token === 'native')
            return BigInt(await rpc.getBalance(new PublicKey(walletAddress)));
        // if (token.chain !== chain) {
        //   const tb = await getTokenBridge(rpc);
        //   token = { chain: chain, address: await tb.getWrappedAsset(token) };
        // }
        const splToken = await rpc.getTokenAccountsByOwner(new PublicKey(walletAddress), { mint: new PublicKey(token.address.toUint8Array()) });
        if (!splToken.value[0])
            return null;
        const balance = await rpc.getTokenAccountBalance(splToken.value[0].pubkey);
        return BigInt(balance.value.amount);
    }
    SolanaUtils.getBalance = getBalance;
    async function sendWait(chain, rpc, stxns) {
        const txhashes = [];
        // TODO: concurrent?
        let lastTxHash;
        for (const stxn of stxns) {
            const txHash = await rpc.sendRawTransaction(stxn);
            // TODO: throw error?
            if (!txHash)
                continue;
            lastTxHash = txHash;
            txhashes.push(txHash);
        }
        // TODO: allow passing commitment level in? this method is also deprecated...
        await rpc.confirmTransaction(lastTxHash, 'finalized');
        return txhashes;
    }
    SolanaUtils.sendWait = sendWait;
    async function getCurrentBlock(rpc) {
        return await rpc.getSlot();
    }
    SolanaUtils.getCurrentBlock = getCurrentBlock;
    async function chainFromRpc(rpc) {
        const conn = rpc;
        const gh = await conn.getGenesisHash();
        const netChain = solGenesisHashToNetworkChainPair.get(gh);
        if (!netChain)
            throw new Error(`No matching genesis hash to determine network and chain: ${gh}`);
        const [network, chain] = netChain;
        return [network, chain];
    }
    SolanaUtils.chainFromRpc = chainFromRpc;
})(SolanaUtils || (SolanaUtils = {}));
//# sourceMappingURL=platformUtils.js.map