import { ChainId, Network, TokenBridge, ChainAddress, VAA, TokenId, RpcConnection, NativeAddress } from '@wormhole-foundation/connect-sdk';
import { Connection } from '@solana/web3.js';
import { Program } from '@project-serum/anchor';
import { Wormhole as WormholeCore } from '../utils/types/wormhole';
import { TokenBridge as TokenBridgeContract } from '../utils/types/tokenBridge';
import { SolanaContracts } from '../contracts';
import { SolanaUnsignedTransaction } from '../unsignedTransaction';
import { SolanaChainName, UniversalOrSolana } from '../types';
export declare class SolanaTokenBridge implements TokenBridge<'Solana'> {
    readonly network: Network;
    readonly chain: SolanaChainName;
    readonly connection: Connection;
    readonly contracts: SolanaContracts;
    readonly chainId: ChainId;
    readonly tokenBridge: Program<TokenBridgeContract>;
    readonly coreBridge: Program<WormholeCore>;
    private constructor();
    static fromProvider(connection: RpcConnection<'Solana'>, contracts: SolanaContracts): Promise<SolanaTokenBridge>;
    isWrappedAsset(token: UniversalOrSolana): Promise<boolean>;
    getOriginalAsset(token: UniversalOrSolana): Promise<TokenId>;
    hasWrappedAsset(token: TokenId): Promise<boolean>;
    getWrappedAsset(token: TokenId): Promise<NativeAddress<'Solana'>>;
    isTransferCompleted(vaa: VAA<'Transfer'> | VAA<'TransferWithPayload'>): Promise<boolean>;
    createAttestation(token: UniversalOrSolana, sender: UniversalOrSolana): AsyncGenerator<SolanaUnsignedTransaction>;
    submitAttestation(vaa: VAA<'AttestMeta'>, sender: UniversalOrSolana): AsyncGenerator<SolanaUnsignedTransaction>;
    private transferSol;
    transfer(sender: UniversalOrSolana, recipient: ChainAddress, token: UniversalOrSolana | 'native', amount: bigint, payload?: Uint8Array): AsyncGenerator<SolanaUnsignedTransaction>;
    private postVaa;
    redeem(sender: UniversalOrSolana, vaa: VAA<'Transfer'> | VAA<'TransferWithPayload'>, unwrapNative?: boolean): AsyncGenerator<SolanaUnsignedTransaction>;
    getWrappedNative(): Promise<NativeAddress<'Solana'>>;
    private createUnsignedTx;
}
//# sourceMappingURL=tokenBridge.d.ts.map