import { PublicKey, SystemProgram, SYSVAR_CLOCK_PUBKEY, SYSVAR_RENT_PUBKEY, } from '@solana/web3.js';
import { createReadOnlyNftBridgeProgramInterface } from '../program';
import { deriveClaimKey, derivePostedVaaKey } from '../../wormhole';
import { deriveEndpointKey, deriveNftBridgeConfigKey, deriveUpgradeAuthorityKey, } from '../accounts';
import { BpfLoaderUpgradeable, deriveUpgradeableProgramKey } from '../../utils';
import { toChainId } from '@wormhole-foundation/connect-sdk';
export function createRegisterChainInstruction(connection, nftBridgeProgramId, wormholeProgramId, payer, vaa) {
    const methods = createReadOnlyNftBridgeProgramInterface(nftBridgeProgramId, connection).methods.registerChain();
    // @ts-ignore
    return methods._ixFn(...methods._args, {
        accounts: getRegisterChainAccounts(nftBridgeProgramId, wormholeProgramId, payer, vaa),
        signers: undefined,
        remainingAccounts: undefined,
        preInstructions: undefined,
        postInstructions: undefined,
    });
}
export function getRegisterChainAccounts(nftBridgeProgramId, wormholeProgramId, payer, vaa) {
    return {
        payer: new PublicKey(payer),
        config: deriveNftBridgeConfigKey(nftBridgeProgramId),
        endpoint: deriveEndpointKey(nftBridgeProgramId, toChainId(vaa.payload.foreignChain), vaa.payload.foreignAddress.toUint8Array()),
        vaa: derivePostedVaaKey(wormholeProgramId, Buffer.from(vaa.hash)),
        claim: deriveClaimKey(nftBridgeProgramId, vaa.emitterAddress.toUint8Array(), toChainId(vaa.emitterChain), vaa.sequence),
        rent: SYSVAR_RENT_PUBKEY,
        systemProgram: SystemProgram.programId,
        wormholeProgram: new PublicKey(wormholeProgramId),
    };
}
export function createUpgradeContractInstruction(connection, nftBridgeProgramId, wormholeProgramId, payer, vaa, spill) {
    const methods = createReadOnlyNftBridgeProgramInterface(nftBridgeProgramId, connection).methods.upgradeContract();
    // @ts-ignore
    return methods._ixFn(...methods._args, {
        accounts: getUpgradeContractAccounts(nftBridgeProgramId, wormholeProgramId, payer, vaa, spill),
        signers: undefined,
        remainingAccounts: undefined,
        preInstructions: undefined,
        postInstructions: undefined,
    });
}
export function getUpgradeContractAccounts(nftBridgeProgramId, wormholeProgramId, payer, vaa, spill) {
    return {
        payer: new PublicKey(payer),
        vaa: derivePostedVaaKey(wormholeProgramId, Buffer.from(vaa.hash)),
        claim: deriveClaimKey(nftBridgeProgramId, vaa.emitterAddress.toUint8Array(), toChainId(vaa.emitterChain), vaa.sequence),
        upgradeAuthority: deriveUpgradeAuthorityKey(nftBridgeProgramId),
        spill: new PublicKey(spill === undefined ? payer : spill),
        implementation: new PublicKey(vaa.payload.newContract.toUint8Array()),
        programData: deriveUpgradeableProgramKey(nftBridgeProgramId),
        nftBridgeProgram: new PublicKey(nftBridgeProgramId),
        rent: SYSVAR_RENT_PUBKEY,
        clock: SYSVAR_CLOCK_PUBKEY,
        bpfLoaderUpgradeable: BpfLoaderUpgradeable.programId,
        systemProgram: SystemProgram.programId,
    };
}
//# sourceMappingURL=governance.js.map